@@ -48,6 +48,7 @@ public class WSDLReaderImpl implements WSDLReader
 
   protected boolean verbose = true;
   protected boolean importDocuments = true;
+  protected boolean parseSchema = true;
   protected ExtensionRegistry extReg = null;
   protected String factoryImplName = null;
   protected WSDLLocator loc = null;
@@ -80,6 +81,16 @@ public class WSDLReaderImpl implements WSDLReader
    *         retrieved and processed.</td>
    *     <td><center>true</center></td>
    *   </tr>
+   *   <tr>
+   *     <td><center>com.ibm.wsdl.parseXMLSchemas</center></td>
+   *     <td>If set to true, the schema documents inlined and import directly
+   *         or indrectly will be retrieved as javax.wsdl.extensions.schema.Schema
+   *         objects and referred to in the Definition. This is the default (only)
+   *         behaviour from JWSDL 1.2. Which is why the default for this feature is true. 
+   *         However, prior to JWSDL 1.2 the only behaviour was not to parse the schema
+   *         files. Setting this feature to false will prevent the schemas being parsed.</td>
+   *     <td><center>true</center></td>
+   *   </tr>
    * </table>
    * <p>
    * All feature names must be fully-qualified, Java package style. All
@@ -109,6 +120,10 @@ public class WSDLReaderImpl implements WSDLReader
     {
       importDocuments = value;
     }
+    else if (name.equals(Constants.FEATURE_PARSE_SCHEMA))
+    {
+      parseSchema = value;
+    }
     else
     {
       throw new IllegalArgumentException("Feature name '" + name +
@@ -589,9 +604,16 @@ public class WSDLReaderImpl implements WSDLReader
       }
       else if ((SchemaConstants.XSD_QNAME_LIST).contains(tempElType))
       {
-      	//the element qname indicates it is a schema.
-        types.addExtensibilityElement(
-          parseSchema(Types.class, tempEl, def));
+        if (parseSchema)
+        {
+      	  //the element qname indicates it is a schema.
+          types.addExtensibilityElement(
+            parseSchema(Types.class, tempEl, def));
+        }
+        else 
+        {
+          types.addExtensibilityElement(parseExtensibilityElementAsDefaultExtensiblityElement(Types.class, tempEl, def));        	
+        }
       }
       else
       {
@@ -970,6 +992,8 @@ public class WSDLReaderImpl implements WSDLReader
       tempEl = DOMUtils.getNextSiblingElement(tempEl);
     }
 
+    parseExtensibilityAttributes(bindingEl, Binding.class, binding, def);
+    
     return binding;
   }
 
@@ -1126,7 +1150,9 @@ public class WSDLReaderImpl implements WSDLReader
 
       tempEl = DOMUtils.getNextSiblingElement(tempEl);
     }
-
+    
+    parseExtensibilityAttributes(bindingInputEl, BindingInput.class, bindingInput, def);
+    
     return bindingInput;
   }
 
@@ -1167,6 +1193,8 @@ public class WSDLReaderImpl implements WSDLReader
       tempEl = DOMUtils.getNextSiblingElement(tempEl);
     }
 
+    parseExtensibilityAttributes(bindingOutputEl, BindingOutput.class, bindingOutput, def);
+
     return bindingOutput;
   }
 
@@ -1331,6 +1359,8 @@ public class WSDLReaderImpl implements WSDLReader
                                               Definition def)
                                                 throws WSDLException
   {
+    if (attrExt == null) return;
+    
     List nativeAttributeNames = attrExt.getNativeAttributeNames();
     NamedNodeMap nodeMap = el.getAttributes();
     int length = nodeMap.getLength();
@@ -1676,13 +1706,13 @@ public class WSDLReaderImpl implements WSDLReader
       op.setStyle(style);
     }
 
+    parseExtensibilityAttributes(opEl, Operation.class, op, def);
+    
     if (retrieved)
     {
       op = null;
     }
 
-    parseExtensibilityAttributes(opEl, Operation.class, op, def);
-    
     return op;
   }
 
@@ -1825,7 +1855,9 @@ public class WSDLReaderImpl implements WSDLReader
 
       ExtensionDeserializer extDS = extReg.queryDeserializer(parentType,
                                                              elementType);
-
+      NamedNodeMap attrs = el.getAttributes();
+      registerNSDeclarations(attrs, def);
+      
       return extDS.unmarshall(parentType, elementType, el, def, extReg);
     }
     catch (WSDLException e)
@@ -1839,6 +1871,61 @@ public class WSDLReaderImpl implements WSDLReader
     }
   }
 
+  /**
+   * Parse the element using the ExtensionRegistry default deserializer instead using the one
+   * registered. The default deserializer will create an UnknownExtensibilityElement from the element. 
+   * @param parentType
+   * @param el
+   * @param def
+   * @return An instance of the default ExtensibilityElement as registered with the ExtensionRegistry 
+   * @throws WSDLException
+   */
+  protected ExtensibilityElement parseExtensibilityElementAsDefaultExtensiblityElement(
+      Class parentType, Element el, Definition def) throws WSDLException
+  {
+    QName elementType = QNameUtils.newQName(el);
+
+    String namespaceURI = el.getNamespaceURI();
+
+    try
+    {
+      if (namespaceURI == null || namespaceURI.equals(Constants.NS_URI_WSDL))
+      {
+        throw new WSDLException(WSDLException.INVALID_WSDL,
+            "Encountered illegal extension element '" + elementType
+                + "' in the context of a '" + parentType.getName()
+                + "'. Extension elements must be in "
+                + "a namespace other than WSDL's.");
+      }
+
+      ExtensionRegistry extReg = def.getExtensionRegistry();
+
+      if (extReg == null)
+      {
+        throw new WSDLException(WSDLException.CONFIGURATION_ERROR,
+            "No ExtensionRegistry set for this "
+                + "Definition, so unable to deserialize " + "a '" + elementType
+                + "' element in the " + "context of a '" + parentType.getName()
+                + "'.");
+      }
+
+      ExtensionDeserializer extDS = extReg.getDefaultDeserializer();
+      
+      NamedNodeMap attrs = el.getAttributes();
+      registerNSDeclarations(attrs, def);
+      
+      return extDS.unmarshall(parentType, elementType, el, def, extReg);
+    } catch (WSDLException e)
+    {
+      if (e.getLocation() == null)
+      {
+        e.setLocation(XPathUtils.getXPathExprFromNode(el));
+      }
+
+      throw e;
+    }
+  }
+  
   protected Input parseInput(Element inputEl, Definition def)
     throws WSDLException
   {
